--InCalcIcon.lua
--Written by Davinna
-- v1.2
--Creates the drag and drop graphic that can open and close the calculator


ToggleButton = class(Turbine.UI.Window)

function ToggleButton:Constructor(table, calcWindow)
	Turbine.UI.Window.Constructor(self)
	
	--Button Static Properties
	self:SetBackground("DavsPlugins/InCalc/Resources/MainIcon.tga")
	self:SetSize(32,32)
	
	--Button Configured Properties
	self:SetPosition(table.IconX, table.IconY)
	self:SetOpacity(table.IconOpacity)
	self:SetVisible(table.IconShowOnStart)
	
	DavsPlugins.InCalc.Utils.ShowHideUI(self, table.IconShowOnStart)
	local ToolTip = DavsPlugins.InCalc.Utils.MakeToolTip(self, calcWindow.Strings["iconTooltip"])
	
	--Event Handlers
	self.MouseDown = function(sender, args)
		self.dragStartX, self.dragStartY = args.X, args.Y
		self.dragging = true
	end --mouse down
	
	self.MouseClick = function( sender, args )
		if ( args.Button == Turbine.UI.MouseButton.Right ) then
			calcWindow:SetVisible(not calcWindow:IsVisible())
		end --if
	end --mouse click function
	
	self.MouseMove = function( sender, args)
		local left, top = self:GetPosition()
		if self.dragging then
			self:SetPosition( left + ( args.X - self.dragStartX ), top + ( args.Y - self.dragStartY ) )
		end--if
		
		ToolTip:SetVisible(false)
	end --mouse move function
	
	self.MouseUp = function( sender, args )
	
		local screenWidth, screenHeight = Turbine.UI.Display.GetSize()
		if self:GetLeft() < 0 then self:SetLeft( 0 ) end
		if self:GetLeft() + self:GetWidth() > screenWidth then self:SetLeft( screenWidth - self:GetWidth() ) end
		if self:GetTop() < 0 then self:SetTop( 0 ) end
		if self:GetTop() + self:GetHeight() > screenHeight then self:SetTop( screenHeight - self:GetHeight() ) end
		self.dragging = false
		
		table.IconX, table.IconY = self:GetPosition()
	end--mouse up function	
	
	self.MouseHover = function(sender, args)
				
		if self:IsVisible() then
			local iconX, iconY = self:GetPosition()
			local screenWidth, screenHeight = Turbine.UI.Display.GetSize()
			if iconY < screenHeight/2 then --top half of the screen
				if iconX < screenWidth/2 then --icon is in top left area of screen put tooltip to the bottom right
					ToolTip:SetPosition(iconX+35, iconY+35)
				else -- icon is in the top right area of the screen put the tooltip to the bottom left 
					ToolTip:SetPosition(iconX-200, iconY+35)
				end
			else--botton half of screen
				if iconX < screenWidth/2 then --icon is in bottom left area of screen put tooltip to the top right
					ToolTip:SetPosition(iconX+35, iconY-35)
				else -- icon is in the bottom right area of the screen put the tooltip to the top left 
					ToolTip:SetPosition(iconX-200, iconY-35)
				end				
			end
			
			ToolTip:SetVisible(true)
		end--if		
	end--mouse hover	
end--toggle button constructor
